@@ -234,6 +234,15 @@ def make_application(
     if debug:
         getattr(app, "logger").level = 10
 
+    @app.add_method
+    def can_redirect(request: Request) -> bool:
+        remote_hostname = urlsplit("http://" + request.host).hostname or "localhost"
+        if base_url_is_localhost:
+            return is_private(remote_hostname) if resolve_localhost else is_localhost(remote_hostname)
+        elif base_url_is_private:
+            return is_private(remote_hostname)
+        return True
+
     @app.add_method
     async def redirect_request(
         request: Request, 
@@ -307,18 +316,9 @@ def make_application(
         redirect_first: bool = False, 
     ) -> Response:
         if url is None:
-            if redirect_first and request.method.upper() in ("GET", "HEAD"):
+            if redirect_first and request.method.upper() in ("GET", "HEAD") and can_redirect(request):
                 from blacksheep import redirect
-                response = redirect(base_url + str(request.url))
-                remote_hostname = urlsplit("http://" + request.host).hostname or "localhost"
-                if base_url_is_localhost:
-                    if is_private(remote_hostname) if resolve_localhost else is_localhost(remote_hostname):
-                        return response
-                elif base_url_is_private:
-                    if is_private(remote_hostname):
-                        return response
-                else:
-                    return response
+                return redirect(base_url + str(request.url))
             http_resp = await redirect_request(request, timeout=timeout)
             response, _ = await make_response(request, http_resp)
             return response
